@@ -1,8 +1,8 @@
 import pandas as pd
-from src.gda_analysis import validation_tests as vtests
+from src.gda_analysis.validation_tests import validation_tests as vtests
 import sys
 
-PATH_OF_MERGED_DATA = '/Users/tovahallas/projects/gda_data/raw_data/merged_vcf_gs_r01.xlsx'
+PATH_OF_MERGED_DATA = '/Users/tovahallas/projects/gda_data/raw_data/merged_vcf_gs.xlsx'
 PATH_OF_VALIDATED = '/Users/tovahallas/projects/test2/validated_merge_r01.xlsx'
 
 COLS_LIST = ['id', 'chrom', 'pos', 'ref', 'alt', 'gt', 'allele1 - top', 'allele2 - top', 'allele1 - forward',
